@@ -1,6 +1,4 @@
 #!/usr/bin/env python2.5
-import sys
-sys.path.append('/opt/tracker-cfg/tracker-config')
 import trackercfgmain
 import gtk
 prefs = trackercfgmain.TrackerPrefs()
